pub struct CountAllCollections {}Trait Implementations
Sourceimpl CacheKey for CountAllCollections
impl CacheKey for CountAllCollections
Sourceimpl Clone for CountAllCollections
impl Clone for CountAllCollections
Sourcefn clone(&self) -> CountAllCollections
fn clone(&self) -> CountAllCollections
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CountAllCollections
impl Debug for CountAllCollections
Sourceimpl Default for CountAllCollections
impl Default for CountAllCollections
Sourcefn default() -> CountAllCollections
fn default() -> CountAllCollections
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CountAllCollections
impl<'de> Deserialize<'de> for CountAllCollections
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for CountAllCollections
impl Hash for CountAllCollections
Sourceimpl ReportHandler for CountAllCollections
impl ReportHandler for CountAllCollections
type Output = CollectionCount
Sourcefn compute(
&self,
ctx: ReportContext,
) -> impl Materialize<Arc<Self::Output>, Definite>
fn compute( &self, ctx: ReportContext, ) -> impl Materialize<Arc<Self::Output>, Definite>
Compute the report output as a reactive pipeline. Read more
Sourceimpl ReportIdStatic for CountAllCollections
impl ReportIdStatic for CountAllCollections
fn report_id_static() -> &'static str
Sourceimpl ReportOutputType for CountAllCollections
impl ReportOutputType for CountAllCollections
type Output = CollectionCount
Sourceimpl Serialize for CountAllCollections
impl Serialize for CountAllCollections
Sourceimpl TS for CountAllCollections
impl TS for CountAllCollections
Sourcetype WithoutGenerics = CountAllCollections
type WithoutGenerics = CountAllCollections
If this type does not have generic parameters, then
The only requirement for these dummy types is that
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or (). The only requirement for these dummy types is that
EXPORT_TO must be None. Read moreSourcetype OptionInnerType = CountAllCollections
type OptionInnerType = CountAllCollections
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn decl_concrete(cfg: &Config) -> String
fn decl_concrete(cfg: &Config) -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl(cfg: &Config) -> String
fn decl(cfg: &Config) -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline(cfg: &Config) -> String
fn inline(cfg: &Config) -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened(cfg: &Config) -> String
fn inline_flattened(cfg: &Config) -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
T should be exported, relative to the output directory.
The returned path does not include any base directory. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn dependencies(cfg: &Config) -> Vec<Dependency>where
Self: 'static,
fn dependencies(cfg: &Config) -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
fn export(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
fn export_all(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string(cfg: &Config) -> Result<String, ExportError>where
Self: 'static,
fn export_to_string(cfg: &Config) -> Result<String, ExportError>where
Self: 'static,