SetShotArgs

Struct SetShotArgs 

pub struct SetShotArgs {
    pub shot_id: ShotId,
    pub library_id: String,
    pub streamer_id: String,
    pub name: String,
    pub kind: ShotKind,
    pub target_name: String,
    pub translation_speed_cm_s: f32,
    pub rotation_speed_deg_s: f32,
    pub hold_duration_ms: u64,
    pub travel_duration_ms: u64,
    pub default_entry_mode: ShotEntryMode,
    pub shot_index: u32,
}

Fields

shot_id: ShotIdlibrary_id: Stringstreamer_id: Stringname: Stringkind: ShotKindtarget_name: Stringtranslation_speed_cm_s: f32rotation_speed_deg_s: f32hold_duration_ms: u64travel_duration_ms: u64default_entry_mode: ShotEntryModeshot_index: u32

Persistent shot label. Keep the established wire name so currently deployed clients remain compatible while Rust uses the correct taxonomy.